@@ -22,11 +22,11 @@ spacy.load('en_core_web_sm')
 
 from os import listdir
 import logging
-from punctuation.logs.logger import logging_function
+## from punctuation.logs.logger import logging_function
 logger = logging.getLogger(__name__)
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def get_tokens(text, parser):
     return parser(text)
 
