@@ -10,7 +10,7 @@ import numpy as np
 import pandas as pd
 import gutenberg.acquire
 import logging
-from punctuation.logs.logger import logging_function
+## from punctuation.logs.logger import logging_function
 from punctuation.utils.utils import splitter_function
 logger = logging.getLogger(__name__)
 
@@ -18,30 +18,30 @@ from gutenberg.query import list_supported_metadatas
 print(list_supported_metadatas())
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def get_max_book_id():
     max_book_id = 1000
     return max_book_id
 
-@logging_function(logger)
+#@logging_function(logger)
 def get_min_book_id():
     min_book_id = 0
     return min_book_id
 
-@logging_function(logger)
+#@logging_function(logger)
 def get_list_book_id():
     list_book_id = range(0,1000)
     return list_book_id
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def random_book_ids(n , list_n=None):
     if list_n is None:
         list_n = get_list_book_id()
     return np.random.choice(list_n, n).tolist()
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def random_book_id(list_n=None):
     if list_n is None:
         list_n = get_list_book_id()
