@@ -10,21 +10,22 @@ import pickle
 import numpy as np
 import pandas as pd
 import sys
+import wget
 import os
 import logging
 from string import ascii_letters
 from punctuation.config import options
 from multiprocessing import Pool, cpu_count
-from punctuation.logs.logger import logging_function # Inherit the logger from the calling function
+## from punctuation.logs.logger import logging_function # Inherit the logger from the calling function
 logger = logging.getLogger(__name__)
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def trial():
     print('Success!')
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def save_as_pickled_object(obj, filepath):
     """
     This is a defensive way to write pickle.write, allowing for very large files on all platforms
@@ -36,7 +37,7 @@ def save_as_pickled_object(obj, filepath):
         for idx in range(0, n_bytes, max_bytes):
             f_out.write(bytes_out[idx:idx+max_bytes])
 
-@logging_function(logger)
+#@logging_function(logger)
 def try_to_load_as_pickled_object_or_None(filepath):
     """
     This is a defensive way to write pickle.load, allowing for very large files on all platforms
@@ -53,16 +54,21 @@ def try_to_load_as_pickled_object_or_None(filepath):
         return None
     return obj
 
-def load_corpus(path='data/pickle/corpus_features.p'):
+def load_corpus(path='data/pickle/punctuation_stylometry.p'):
     res = try_to_load_as_pickled_object_or_None(path)
     if res is not None:
         return res
-    if 'genre' in path:
-        res = define_genre(path=path)
-        return res
-    if 'author' in path:
-        #TODO
-        pass
+    else:
+        print('Downloading the corpus.. please wait..')
+        url = "https://zenodo.org/record/3605100/files/punctuation_stylometry.p?download=1"
+        wget.download(url, path)
+        return try_to_load_as_pickled_object_or_None(path)
+#    if 'genre' in path:
+#        res = define_genre(path=path)
+#        return res
+#    if 'author' in path:
+#        #TODO
+#        pass
 
 def define_genre(df=None, genres_to_include=options.genres_to_include,
                  path='data/pickle/genre_features.p'):
@@ -77,7 +83,7 @@ def chunks(l, n):
    return list(l[i:i+n] for i in range(0, len(l), n))
 
 
-@logging_function(logger)
+#@logging_function(logger)
 def splitter_function(txt, first_term, last_term):
     if txt is None:
         return None
